# =========================================================================== #
# Gemspec for Project FtpParadise.
# =========================================================================== #
require 'ftp_paradise/version/version.rb'

Gem::Specification.new { |s|

  s.name    = 'ftp_paradise'
  s.version = FtpParadise::VERSION
  s.date    = Time.now.strftime('%Y-%m-%d')

  DESCRIPTION = <<-EOF

This project aims to provide some convenience bindings and addon-classes
for the Ruby-FTP base module.

The basic idea for this project was to make working with FTP-related
code simpler, and more convenient. This is why the project focuses
both on commandline use, interactive commandline use, as well as
GUI components (via ruby-gtk3 primarily).

Please be aware that since as of the year 2020, this project is in a
low-effort maintenance mode only, though.

Bug fixes may still happen, as well as improvements made to the 
documentation - but by and large, I am no longer modifying this 
project that much anymore. My peak FTP days in regards to this
project were mostly from 2010 to 2014. Since then I have found
fewer use cases for this project.

For more information about the ftp_paradise project, please have a look
at the online documentation at https://www.rubydoc.info/gems/ftp_paradise/
or within the doc/ subdirectory of this gem.

EOF

  s.summary     = DESCRIPTION
  s.description = DESCRIPTION

  # =============================================================== #
  # Show this when a user installs this project.
  # =============================================================== #
  s.post_install_message = <<-EOF

  The interactive file, which can be started by typing "iftp",
  requires a library called configuration.

  This is NOT the one available at rubygems.org - but instead can
  be downloaded here:

      wget http://shevegen.bplaced.net/configuration-1.0.21.gem

  Please install only the above configuration-gem variant, not the
  other gem called "configuration". (You can extract the gem and
  look at it before you install it of course. Its sole purpose
  is to read in a bunch of .yml yaml files to provide a proper
  base configuration for a project.)

  If you wish to start the interactive FTP, the file can be
  found at:

      bin/iftp

  And should on most Linux systems end up on:

      /usr/bin/iftp

  if the --prefix is at /usr (obviously, if you install into
  your home directory, then it will be at another location;
  rubygems should take care of this).

  So just typing "iftp" should suffice to start the interactive FTP
  component, but keep in mind that you need to download the
  configuration gem listed above first.

  You can disable the colour-section of the interactive FTP
  by issuing:

      iftp --disable-colours

  You can also batch-upload some scripts through the command
  called:

      ftp_upload

  ftp_upload --help should give you some information on how
  to use it.

  Consider installing the "roebe" gem for making "Configuration"
  available.

  Thank you and have fun!

  EOF

  s.authors     = ['Robert A. Heiler']
  s.email       = 'shevegen@gmail.com'
  s.license     = 'GPL-2.0'
  s.files       = Dir['**/*']
  s.files       << ['README.md']
  s.files       = s.files.flatten
  s.executables = Dir['bin/*'].map { |entry| File.basename(entry) }
  s.require_paths = ["lib"]

  s.homepage    = 'http://rubygems.org/gems/ftp_paradise'

  s.required_ruby_version     = '>= '+RUBY_VERSION
  s.required_rubygems_version = '>= '+Gem::VERSION
  s.rubygems_version          = '>= '+Gem::VERSION

  # =============================================================== #
  # Dependencies for this project:
  # =============================================================== #
  s.add_dependency 'cliner'
  s.add_dependency 'colours'
  s.add_dependency 'convert_global_env'
  s.add_dependency 'rcfiles'
  s.add_dependency 'opn'
  s.add_dependency 'verbose_truth'
  s.add_dependency 'gtk_paradise'

}